#!/bin/bash

# SPDX-FileCopyrightText: 2024 2024 Brandenburgische Technische Universität Cottbus-Senftenberg
#
# SPDX-License-Identifier: BSD-3-Clause

DEBUG_MODE=false

#######################################
# Determines if current environment is located within HPC infrastructure
# Globals:
#   None
# Arguments:
#   None
# Outputs:
#   None
# Returns:
#   0 if current environment is on HPC infrastructure, 1 if otherwise
#######################################
is_hpc_environment() {
    if [[ -f "/etc/profile.d/modules.sh" && -d "/sw/spack-levante" ]]; then
        return 0
    else
        return 1
    fi
}

#######################################
# Loads necessary plugin modules on HPC infrastructure
# Globals:
#   None
# Arguments:
#   None
# Outputs:
#   None
# Returns:
#   None
#######################################
load_hpc_modules() {
    echo "Loading HPC modules..."
    source /etc/profile.d/modules.sh
    module use /sw/spack-levante/spack/modules
    module load cdo/2.2.2-gcc-11.2.0 nco/5.0.6-gcc-11.2.0
}

#######################################
# Sets debug level according to given settings
# Globals:
#   DEBUG_MODE
# Arguments:
#   $1: Debug setting (true/false) determining debug level
# Outputs:
#   Sets debug mode to true or false depending on given settings
# Returns:
#   None
#######################################
debug_level() {
    if [ "$1" = "true" ] || [ "$1" = "True" ]; then
        DEBUG_MODE=true
    else
        DEBUG_MODE=false
    fi
}

#######################################
# Formats current timestamp and return it
# Globals:
#   None
# Arguments:
#   None
# Outputs:
#   None
# Returns:
#   Formats and returns current timestamp
#######################################
timestamp() {
    date '+%Y-%m-%d %H:%M:%S'
}

#######################################
# Adds Debug flag and timestamp to given message
# Globals:
#   DEBUG_MODE
# Arguments:
#   $1: Message
# Outputs:
#   Echos tagged(DEBUG)  message with timestamp
# Returns:
#   None
#######################################
log_debug() {
    if [ "$DEBUG_MODE" = true ]; then
        echo "[DEBUG] $(timestamp) $1"
    fi
}

#######################################
# Adds Error flag and timestamp to given message
# Globals:
#   DEBUG_MODE
# Arguments:
#   $1: Message
# Outputs:
#   Echos tagged(ERROR)  message with timestamp
# Returns:
#   None
#######################################
log_error() {
    echo "[ERROR] $(timestamp) $1" >&2
}
